import Queue from "queue";
import { EmitterSubscription, KeyboardEvent, KeyboardEventName } from "react-native";
import { IDeviceModel } from "./device-dimensions/deviceDimensions";
import { KeyboardState } from "./keyboardTransitions";
import { KeyboardTransitionTimer } from "./KeyboardTransitionTimer";
export interface IOSKeyboardEvent extends KeyboardEvent {
    eventType: KeyboardEventName;
}
declare type ListenerCallback = (currentState: KeyboardState, previousState: KeyboardState) => void;
export interface IOSKeyboardEventsOptions {
    deviceModel?: IDeviceModel;
    keyboardEventDebounceTime?: number;
}
export declare class IOSKeyboardEvents {
    keyboardEventSubscriptions: EmitterSubscription[];
    listeners: {
        [key: string]: ListenerCallback;
    };
    lastKeyboardEvent: IOSKeyboardEvent | undefined;
    lastKeyboardState: KeyboardState;
    keyboardState: KeyboardState;
    keyboardTransitionTimer: KeyboardTransitionTimer;
    keyboardEventQueue: Queue;
    keyboardEventDebounceTime: number;
    deviceModel: IDeviceModel;
    constructor(deviceModel: IDeviceModel, keyboardEventDebounceTime: number);
    addListener(listenerName: string, callback: ListenerCallback): void;
    removeListener(listenerName: string): void;
    close(): void;
    getKeyboardState(): KeyboardState;
    getDeviceModelInformation(): IDeviceModel;
    private startKeyboardListeners;
    private onKeyboardEvent;
    private updateKeyboardState;
    private updateListeners;
}
declare const createIOSKeyboardEvents: (options?: IOSKeyboardEventsOptions) => IOSKeyboardEvents;
export declare const getDevicePlatform: () => import("react-native").PlatformOSType;
export default createIOSKeyboardEvents;
